@@ -242,7 +242,7 @@ BayonneDriver *BayonneDriver::loadDriver(const char *id)
 #ifdef	WIN32
 #ifdef	HAVE_TESTING
 	if(!prefix && provision_test)
-#ifdef	NDEBUG
+#ifdef	_DEBUG
 		prefix = "DEBUG";
 #else
 		prefix = "RELEASE";
