@@ -1009,25 +1009,31 @@ void BayonneSession::check(void)
 	Line *line = getLine();
 	Name *scr = getName();
 
-	if(state.menu)
-	{
-		dtmf = enableDTMF();
-		return;
-	}
+        if(state.menu)
+        {
+                dtmf = enableDTMF();
+                return;
+        }
 
-	if(!image || !line)
-	{
-		dtmf = false;
-		return;
-	}
+        if(!image || !line)
+        {
+                dtmf = false;
+                return;
+        }
 
-	if((frame[stack].mask & 0x8) || server->isInput(line))
-	{
-		dtmf = enableDTMF();
-		return;
-	}
+        if(server->isInput(line))
+        {
+                dtmf = enableDTMF();
+                return;
+        }
 
-	disableDTMF();
+        if((frame[stack].mask & 0x8) && (line->mask & 0x08))
+        {
+                dtmf = enableDTMF();
+                return;
+        }
+
+        disableDTMF();
 }
 
 bool BayonneSession::digitEvent(const char *evt)
