@@ -1736,9 +1736,6 @@ bool BayonneSession::filterPosting(Event *event)
 	case DTMF_KEYDOWN:
 		if(!dtmf || !dtmf_digits)
 			return false;
-                line = getLine();
-                if(line && !(line->mask & 0x08))
-                        return false;     
 		digit_count = strlen(dtmf_digits);
 		return true;
 	case STOP_PARENT:
