@@ -33,8 +33,8 @@ TimerPort()
 	cid = 0;
 	did = 0;
 	rtp = NULL;
-	dtmf_payload = Driver::sip.dtmf_payload;
-	data_payload = Driver::sip.data_payload;
+	dtmf_payload = Driver::sip.dtmf_negotiate;
+	data_payload = Driver::sip.data_negotiate;
 	dtmf_inband = Driver::sip.dtmf_inband;
 
 	update_pos = false;
@@ -57,45 +57,25 @@ Session::~Session()
 {
 }
 
-void Session::setDTMFMode(const char *mode)
+void Session::sendDTMFInfo(char digit, unsigned duration)
 {
-	if(!mode)
+	osip_message_t *message = NULL;
+	char dtmf_body[1000];
+
+        snprintf(dtmf_body, sizeof(dtmf_body) - 1,
+                "Signal=%c\r\nDuration=%d\r\n", digit, duration);  
+
+	eXosip_lock();
+	if(eXosip_call_build_info(did, &message) != 0)
 	{
-	       	dtmf_inband = Driver::sip.dtmf_inband;
-        	dtmf_payload = Driver::sip.dtmf_payload;  
+		eXosip_unlock();
 		return;
 	}
 
-	if(!stricmp(mode, "2833") || !stricmp(mode, "rtp"))
-		mode = Driver::sip.getLast("dtmf");
-
-	session->setConst("session.sip_dtmf", mode);
-
-	if(atoi(mode) > 0)
-	{
-		dtmf_inband = false;
-		dtmf_payload = atoi(mode);
-	}
-	else if(!stricmp(mode, "info"))
-	{
-		dtmf_inband = false;
-		dtmf_payload = 0;
-	}
-	else
-	{
-                dtmf_inband = Driver::sip.dtmf_inband;
-                dtmf_payload = Driver::sip.dtmf_payload;  
-	}
-}		
-
-void Session::sendDTMFInfo(char digit, unsigned duration)
-{
-	char dtmf_body[1000];
-	snprintf(dtmf_body, sizeof(dtmf_body) - 1, 
-		"Signal=%c\r\nDuration=%d\r\n", digit, duration);
-        eXosip_lock();
-        eXosip_info_call(did, "application/dtmf-relay", dtmf_body);
-        eXosip_unlock();
+	osip_message_set_body(message, dtmf_body, strlen(dtmf_body));
+	osip_message_set_content_type(message, "application/dtmf-relay");
+	eXosip_call_send_request(did, message);
+	eXosip_unlock();
 }
 
 timeout_t Session::getRemaining(void)
@@ -153,12 +133,12 @@ void Session::stopRTP(void)
 void Session::makeIdle(void)
 {
 	update_pos = false;
-	sipHangup();
-	stopRTP();
+	if(offhook)
+		sipHangup();
 	BayonneSession::makeIdle();
 	dtmf_inband = Driver::sip.dtmf_inband;
-	dtmf_payload = Driver::sip.dtmf_payload;
-	data_payload = Driver::sip.data_payload;
+	dtmf_payload = Driver::sip.dtmf_negotiate;
+	data_payload = Driver::sip.data_negotiate;
 }
 
 bool Session::enterSeize(Event *event)
@@ -166,105 +146,169 @@ bool Session::enterSeize(Event *event)
 	char buf[128];
 	char cref[64];
 	const char *cp, *p, *to, *from = NULL;
+	const char *caller;
 	char *sp;
 	const char *svr;
-	osip_message_t *invite;
+	osip_message_t *invite = NULL;
 	unsigned len;
 	Name *scr = ScriptInterp::getName();
 	Registry *reg = NULL;
-	ScriptImage *img;
+	ScriptImage *img = getImage();
+	char rbuf[16];
+	char sdp[512];
+	const char *rtpmap;
+	const char *route;
 
 	switch(event->id)
 	{
 	case ENTER_STATE:
-		cp = getSymbol("session.sip_dtmf");
-		if(!cp)
-			setDTMFMode(NULL);
-
 		cp = getSymbol("session.dialed");
 		if(!cp)
 		{
 			event->id = DIAL_FAILED;
 			return false;
 		}
+		route = Driver::sip.getLast("outbound");
 		if(!strchr(cp, '@'))
 		{
-			svr = Driver::sip.getLast("outbound");
-			if(!svr)
-				svr = Bayonne::server->getLast("server");
-			snprintf(buf, sizeof(buf), "sip:%s@%s", cp, svr);
+			snprintf(buf, sizeof(buf), "uri.%s", cp);
+			reg = (Registry *)img->getPointer(buf);
+			if(reg && !strnicmp(reg->type, "ext", 3))
+			{
+				snprintf(buf, sizeof(buf), "sip:%s@%s",
+					reg->userid, reg->proxy);
+				if(!route)
+					route = reg->proxy;
+				sp = strrchr(buf, ':');
+				if(sp && !stricmp(sp, ":5060"))
+					*sp = 0;
+				setConst("session.uri_remote", buf);
+				goto dialing;
+			}
 		}
+		if(!strchr(cp, '@'))
+			snprintf(buf, sizeof(buf), "sip:%s@%s", cp, route);
 		else 
 		{
 			if(!strnicmp(cp, "sip:", 4))
-				p = "";
-			else
-				p = "sip:";
-			snprintf(buf, sizeof(buf), "%s%s", p, cp);
-		} 	
-		
-		setConst("session.uri_remote", buf);	
-		cp = strchr(buf, '@');
-		if(cp)
-			setConst("session.server", ++cp);
-		to = getSymbol("session.uri_remote");
-		
-
-		cp = strchr(to, '@');
+				cp += 4;
+			snprintf(buf, sizeof(buf), "sip:%s", cp);	
+		}
+		if(sp && stricmp(sp, ":5060"))
+			sp = 0;
+		setConst("session.uri_remote", buf);
+		cp = getSymbol("session.uri_remote");
+		cp = strchr(cp, '@');
 		if(cp)
 		{
-			snprintf(buf, sizeof(buf), "sipauth.%s", ++cp);
-			sp = strrchr(buf, ':');
-			if(sp && !stricmp(sp, ":5060"))
-				*sp = 0;
-			img = useImage();
+			snprintf(buf, sizeof(buf), "sip.%s", ++cp);
 			reg = (Registry *)img->getPointer(buf);
-			if(reg)
-			{
-				setConst("session.uri_local", reg->uri);
-				from = getSymbol("session.uri_local");
-				setDTMFMode(reg->dtmf);
-			}
-			else
-				setDTMFMode(NULL);
-			endImage(img);
-		}		
-		else	
-			setDTMFMode(NULL);
-
-		if(!from)
+		}
+dialing:
+		if(reg)
 		{
-			snprintf(buf, sizeof(buf) - 2, "sip:%s", scr->name);
-			sp = strchr(buf + 4, ':');
-			if(sp)
-			{
-				*(sp++) = '.';
-				cp = strrchr(scr->name, ':');
-				strcpy(sp, cp + 1);
-			} 
-			len = strlen(buf);
-			buf[len++] = '@';
-			buf[len] = 0;
-			setString(buf + len, sizeof(buf) - len, Driver::sip.getLast("interface"));
+			if(!route)
+				route = reg->proxy;
+			snprintf(rbuf, sizeof(rbuf), "sipreg.%d", reg->regid);
+			setConst("session.registry", rbuf);
+			setConst("session.uri_local", reg->contact);
+		}
+		else
+		{
+			snprintf(buf, sizeof(buf), "sip:anon@%s",
+				Driver::sip.getLast("interface"));
 			setConst("session.uri_local", buf);
-			from = getSymbol("session.uri_local");
-		}				
-		slog.debug("invite %s from %s", to, from);
-		if(eXosip_build_initial_invite(&invite, (char *)to, (char *)from, NULL, "Hello"))
+		}
+			
+		to = getSymbol("session.uri_remote");
+		from = getSymbol("session.uri_local");
+
+		if(!route)
 		{
+			route = strchr(to, '@');
+			if(route)
+				++route;
+		}
+
+		if(!strnicmp(route, "sip:", 4))
+			route += 4;
+
+		snprintf(buf, sizeof(buf), "<sip:%s;lr>", route);
+
+		slog.debug("invite %s from %s using %s", to, from, route);
+		eXosip_lock();
+		if(eXosip_call_build_initial_invite(&invite, 
+			(char *)to, (char *)from, buf, "Bayonne Call"))
+		{
+			eXosip_unlock();
+failure:
 			slog.error("sip: invite invalid");
 			event->id = DIAL_FAILED;
 			return false;
 		}
+		eXosip_unlock();
+		cp = Driver::sip.getLast("localip");
+		data_payload = Driver::sip.data_negotiate;
+		dtmf_payload = Driver::sip.dtmf_negotiate;
+		switch(Driver::sip.info.encoding)
+		{
+		case mulawAudio:
+			data_payload = 0;
+			rtpmap = "a=rtpmap:0 PCMU/8000/1";
+			break;
+		case alawAudio:
+			data_payload = 8;
+			rtpmap = "a=rtpmap:8 PCMA/8000/1";
+			break;
+		case gsmVoice:
+			data_payload = 3;
+			rtpmap = "a=rtpmap:3 GSM/8000/1";
+			break;
+		}			
+		if(dtmf_payload)
+                        snprintf(sdp, sizeof(sdp),
+                                "v=0\r\n"
+                                "o=bayonne 0 0 IN IP4 %s\r\n"
+                                "s=call\r\n"
+                                "c=IN IP4 %s\r\n"
+                                "t=0 0\r\n"
+                                "m=audio %d RTP/AVP %d %d\r\n"
+                                "%s\r\n"
+				"a=rtpmap:%d telephone-events/8000\r\n",
+				cp, cp, 
+				getLocalPort(), data_payload, dtmf_payload,
+				rtpmap, dtmf_payload);
+
+		else
+			snprintf(sdp, sizeof(sdp),
+				"v=0\r\n"
+				"o=bayonne 0 0 IN IP4 %s\r\n"
+				"s=call\r\n"
+				"c=IN IP4 %s\r\n"
+				"t=0 0\r\n"
+				"m=audio %d RTP/AVP %d\r\n"
+				"%s\r\n",
+				cp, cp, 
+				getLocalPort(), data_payload, 
+				rtpmap);
+
+		setSymbol("session.rtpmap", rtpmap);
+
 		eXosip_lock();
-		snprintf(buf, sizeof(buf), "%d", getLocalPort());
+		osip_message_set_body(invite, sdp, strlen(sdp));
+		osip_message_set_content_type(invite, "application/sdp");
+		
 		offhook = true;
 		setSid();
 		snprintf(cref, sizeof(cref), "%s@%s",
 			var_sid, inet_ntoa(local_address.getAddress()));
 		setConst("session.callref", cref);
-		cid = eXosip_initiate_call(invite, cref, NULL, buf);
+		cid = eXosip_call_send_initial_invite(invite);
+		if(cid > 0)
+			eXosip_call_set_reference(cid, cref);
 		eXosip_unlock();
+		if(cid <= 0)
+			goto failure;
 		startTimer(atol(Driver::sip.getLast("invite")));
 		return true;
 	case CALL_CONNECTED:
@@ -272,7 +316,7 @@ bool Session::enterSeize(Event *event)
 		setRunning();
 		return true;
 	case CALL_ANSWERED:
-		startTimer(driver->getPickupTimer());
+		setState(STATE_PICKUP);
 		return true;
 	case CALL_RINGING:
 		stopTimer();
@@ -286,11 +330,10 @@ bool Session::enterSeize(Event *event)
 
 bool Session::enterHangup(Event *event)
 {
-	if(event->id == TIMER_EXPIRED)
+	switch(event->id)
 	{
-		offhook = true;
+	case TIMER_EXPIRED:
 		sipHangup();
-		stopRTP();
 	}
 
 	update_pos = false;
@@ -349,7 +392,7 @@ bool Session::enterPickup(Event *event)
 {
 	if(event->id == ENTER_STATE)
 	{
-		sipAnswer(200);
+		offhook = true;
 		startRTP();
 		startTimer(driver->getPickupTimer());
 		return true;
@@ -373,16 +416,25 @@ bool Session::enterTone(Event *event)
 
 bool Session::enterXfer(Event *event)
 {
-	if(event->id == ENTER_STATE)
+	osip_message_t *refer;
+	int rtn;
+
+	switch(event->id)
 	{
-		if(!eXosip_transfer_call(did, (char *)state.url.ref))
+	case ENTER_STATE:
+		eXosip_lock();
+		eXosip_call_build_refer(did, (char *)state.url.ref, &refer);
+		rtn = eXosip_call_send_request(did, refer);
+		eXosip_unlock();
+		if(!rtn)
 		{
 			setState(STATE_HANGUP);
 			return true;
 		}
 		event->errmsg = "transfer-invalid";
 		event->id = ERROR_STATE;
-	}
+		return false;
+	}	
 	return false;
 }
 
@@ -404,29 +456,13 @@ void Session::clrAudio(void)
 
 void Session::sipHangup(void)
 {
-	if(!offhook)
-		return;
-
 	eXosip_lock();
-	eXosip_terminate_call(cid, did);
+	eXosip_call_terminate(cid, did);
 	eXosip_unlock();
+	stopRTP();
 	offhook = false;
 }
 
-void Session::sipAnswer(int code)
-{
-	char buf[16];
-
-	if(offhook)
-		return;
-
-	snprintf(buf, sizeof(buf), "%d", getLocalPort());
-	eXosip_lock();
-	eXosip_answer_call(did, code, buf);
-	eXosip_unlock();
-	offhook = true;
-}
-
 timeout_t Session::getToneFraming(void)
 {
 	return Driver::sip.info.framing;
