@@ -112,6 +112,7 @@ static Keydata::Define engine[] = {
 	{"userid", ""},
 	{"secret", ""},
 	{"timeslots", "32"},
+	{"driver", "autodetect"},
 	{NULL, NULL}};
 
 #ifdef	WIN32
@@ -511,6 +512,18 @@ bool parseConfig(char **argv)
 	unsigned scrcount = 0;
 	unsigned minslots = 0;
 	bool live = true;
+	const char *cp;
+
+#ifndef	WIN32
+	cp = keyengine.getLast("driver");
+	if(cp && !stricmp(cp, "autodetect"))
+		cp = Process::getEnv("TIMESLOTS");
+	else if(cp && !stricmp(cp, "default"))
+		cp = Process::getEnv("TIMESLOTS");
+
+	if(cp && atoi(cp) > 0)
+		keyengine.setValue("timeslots", cp);
+#endif
 
 retry:
 	if(!*argv)
