@@ -826,14 +826,14 @@ bool Runtime::loadBinder(const char *path)
 #ifdef  WIN32
 #ifdef  HAVE_TESTING
         if(!prefix && Bayonne::provision_test)
-#ifdef  NDEBUG
+#ifdef  _DEBUG
                 prefix = "DEBUG";
 #else    
                 prefix = "RELEASE";
 #endif
 #endif   
         if(!prefix)
-	 	prefix = "C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Binder";
+	 	prefix = "C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Binders";
 #else
 
 #ifdef  HAVE_TESTING
@@ -854,7 +854,7 @@ bool Runtime::loadBinder(const char *path)
 #endif 
 
 #ifdef  WIN32
-        snprintf(pathbuf, sizeof(pathbuf), "%s/%s." RLL_SUFFIX, prefix, path);
+        snprintf(pathbuf, sizeof(pathbuf), "%s/%s.%s" prefix, path, RLL_SUFFIX);
 #else
         snprintf(pathbuf, sizeof(pathbuf), "%s/%s.bin", prefix, path);
 #endif  
@@ -873,7 +873,7 @@ bool Runtime::loadBinder(const char *path)
 
         if(!canAccess(path))
         {
-                Bayonne::errlog("access", "cannot load %s", path);
+                Bayonne::errlog("access", "cannot load  %s", path);
                 return false;
         }  
 
