@@ -45,12 +45,13 @@ using namespace std;
 class ListThread : public ScriptThread, public Dir
 {
 private:
-	const char *prefix, *suffix;
-	Symbol *sym;
+	const char *prefix, *suffix, *after;
+	Symbol *sym, *save;
 	bool longinfo;
 	char filepath[MAX_PATHNAME];
 	unsigned fplen;
 	AudioFile af;
+	char last[65];
 
 	void run(void);
 
